# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["SchemaRetrieveParams"]


class SchemaRetrieveParams(TypedDict, total=False):
    format: Literal["json", "yaml"]

    lang: Literal[
        "af",
        "ar",
        "ar-dz",
        "ast",
        "az",
        "be",
        "bg",
        "bn",
        "br",
        "bs",
        "ca",
        "ckb",
        "cs",
        "cy",
        "da",
        "de",
        "dsb",
        "el",
        "en",
        "en-au",
        "en-gb",
        "eo",
        "es",
        "es-ar",
        "es-co",
        "es-mx",
        "es-ni",
        "es-ve",
        "et",
        "eu",
        "fa",
        "fi",
        "fr",
        "fy",
        "ga",
        "gd",
        "gl",
        "he",
        "hi",
        "hr",
        "hsb",
        "hu",
        "hy",
        "ia",
        "id",
        "ig",
        "io",
        "is",
        "it",
        "ja",
        "ka",
        "kab",
        "kk",
        "km",
        "kn",
        "ko",
        "ky",
        "lb",
        "lt",
        "lv",
        "mk",
        "ml",
        "mn",
        "mr",
        "ms",
        "my",
        "nb",
        "ne",
        "nl",
        "nn",
        "os",
        "pa",
        "pl",
        "pt",
        "pt-br",
        "ro",
        "ru",
        "sk",
        "sl",
        "sq",
        "sr",
        "sr-latn",
        "sv",
        "sw",
        "ta",
        "te",
        "tg",
        "th",
        "tk",
        "tr",
        "tt",
        "udm",
        "ug",
        "uk",
        "ur",
        "uz",
        "vi",
        "zh-hans",
        "zh-hant",
    ]
