# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .collection import Collection

__all__ = ["CollectionListResponse"]

CollectionListResponse: TypeAlias = List[Collection]
