# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .shared.profile import Profile

__all__ = ["ProfileListResponse"]

ProfileListResponse: TypeAlias = List[Profile]
