# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .template import Template

__all__ = ["TemplateListResponse"]

TemplateListResponse: TypeAlias = List[Template]
