# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .tag import Tag

__all__ = ["TagListResponse"]

TagListResponse: TypeAlias = List[Tag]
